aboutsummaryrefslogtreecommitdiff
path: root/helix-view/src
diff options
context:
space:
mode:
authorBlaž Hrastnik2023-09-11 04:14:41 +0000
committerBlaž Hrastnik2023-09-11 04:14:41 +0000
commit060e73a7110fe38cc6ed30ca0cc3abc686e225fa (patch)
treeaf1d36ce5b56d95f9fa07bd06796ef07d955a286 /helix-view/src
parentacef759a5e2e4dab46d037efab8775912639e229 (diff)
Lower idle-timeout to 250ms
The aim is to make it slow enough it only triggers during a typing pause, but not too slow. Initial value was chosen as a safe slow default but I've been using 250 for a while.
Diffstat (limited to 'helix-view/src')
-rw-r--r--helix-view/src/editor.rs4
1 files changed, 2 insertions, 2 deletions
diff --git a/helix-view/src/editor.rs b/helix-view/src/editor.rs
index 86f35e0d..6963867a 100644
--- a/helix-view/src/editor.rs
+++ b/helix-view/src/editor.rs
@@ -244,7 +244,7 @@ pub struct Config {
/// Set a global text_width
pub text_width: usize,
/// Time in milliseconds since last keypress before idle timers trigger.
/// Used for autocompletion, set to 0 for instant. Defaults to 400ms.
#[serde(
serialize_with = "serialize_duration_millis",
deserialize_with = "deserialize_duration_millis"
@@ -817,7 +817,7 @@ impl Default for Config {
auto_completion: true,
auto_format: true,
auto_save: false,
- idle_timeout: Duration::from_millis(400),
+ idle_timeout: Duration::from_millis(250),
preview_completion_insert: true,
completion_trigger_len: 2,
auto_info: true,
@@ -244,7 +244,7 @@ pub struct Config {
pub text_width: usize,
/// Time in milliseconds since last keypress before idle timers trigger.
- /// Used for autocompletion, set to 0 for instant. Defaults to 400ms.
+ /// Used for autocompletion, set to 0 for instant. Defaults to 250ms.
#[serde(
serialize_with = "serialize_duration_millis",